#//-----------------------------------------------
#//TUSB-S01VM用サンプルプログラム (Continuous)
#//Python 用モジュール
#//
#//2024_07_24　株式会社タートル工業
#//Copyright (C) 2024 Turtle Industry Co.,Ltd.
#//-----------------------------------------------

import TUSBSVM
from functools import partial
from SpFuncs import *
import sys

class Tusbs01vm_Device:
    """TUSB-S01VM デバイス操作クラス フォーム"""
    DevId = None                    # デバイスID

    def __init__(self,DevId):
        """イニシャライザ
        
        Arguments:
        DevId           ----    Device Id 0~3
        """
        self.formgen()
        ret = TUSBSVM.Tusbs01vm_Device_Open(DevId)              # デバイスオープン
        if ret == 0:    # 正常オープン
            self.DevId = DevId                                  # デバイスIDをクラスメンバ変数に保持する
            self.form.protocol("WM_DELETE_WINDOW",self.DevClose)
        else:
            ShowInfo(TUSBSVM.GetErrMessage(ret))                # 失敗　エラーメッセージ表示
            self.form.destroy()                                 # フォームを閉じる
    
    def DevClose(self):
        """デバイスを閉じる時の処理"""
        if  self.DevId != None:
            TUSBSVM.Tusbs01vm_Device_Close(self.DevId)          # デバイスクローズ
            self.form.destroy()                                 # フォームを閉じる
            self.DevId = None
    
    # ボタン等ウィジットの操作イベントハンドラ ----------------------
    def BtnStart_on(self):
        """取り込みボタンハンドラ"""
        ret = TUSBSVM.Tusbs01vm_Start_Sample(self.DevId,1)      # 取込開始(取込周期10ms)
        if ret != 0:
            ShowInfo(TUSBSVM.GetErrMessage(ret))
            return
        self.LstbxTemp.delete(0,tk.END)     # 過去のリストボックスの内容を消す
        TotalCnt = 0
        # 値を10個取り込む
        while TotalCnt < 10:
            ret = TUSBSVM.Tusbs01vm_Get_Datas(self.DevId,10)    # データを要求する
            if ret[0] != 0: return
            for dat in ret[1]:
                self.LstbxTemp.insert(tk.END,format(dat,"5.2f")+"V")
                TotalCnt += 1
                if TotalCnt >= 10:
                    break
    
    # フォームとウィジェットを生成する処理---------------------------
    def formgen(self):
        self.form = tk.Tk()
        form = self.form
        form.geometry('293x327')
        form.title('TUSB-S01VMx Sample Program (continuous)')

        self.LstbxTemp = GenListBox(form,0.6,0.7,0.2,0.05)
        self.BtnStart = GetButton(form,"取込",self.BtnStart_on,0.2,0.5,0.85)

# 実行部 ---------------------------------
if __name__=="__main__":
    DevId = 0
    if( len(sys.argv) >= 2 ):
        if sys.argv[1].isdigit():
            DevId = int(sys.argv[1])    # コマンドライン引数でID設定
    tmp = Tusbs01vm_Device(DevId=DevId)
    tmp.form.mainloop()
