#//-----------------------------------------------
#//TUSB-S01VM用サンプルプログラム (Single)
#//Python 用モジュール
#//
#//2024_07_23　株式会社タートル工業
#//Copyright (C) 2024 Turtle Industry Co.,Ltd.
#//-----------------------------------------------

import TUSBSVM
from functools import partial
from SpFuncs import *
import sys

class Tusbs01vm_Device:
    """TUSB-S01VM デバイス操作クラス フォーム"""
    DevId = None                    # デバイスID
    smpl_t = None                   # サンプリングタイマー
    SMPL_BTN_START = "開始"         # 計測開始停止ボタン開始表示文字列
    SMPL_BTN_STOP = "停止"          # 計測開始停止ボタン停止表示文字列

    def __init__(self,DevId):
        """イニシャライザ
        
        Arguments:
        DevId           ----    Device Id 0~15
        """
        self.formgen()
        ret = TUSBSVM.Tusbs01vm_Device_Open(DevId)                  # デバイスオープン
        if ret == 0:    # 正常オープン
            self.DevId = DevId                                      # デバイスIDをクラスメンバ変数に保持する
            self.form.protocol("WM_DELETE_WINDOW",self.DevClose)
            self.smpl_t = intTT(0.1,self.SampleT)                   # モニタータイマー作成、コールバック関数登録
        else:
            ShowInfo(TUSBSVM.GetErrMessage(ret))                    # 失敗エラーメッセージ表示
            self.form.destroy()                                     # フォームを閉じる 
    
    def DevClose(self):
        """デバイスを閉じる時の処理"""
        if self.DevId != None:
            if self.smpl_t != None:
                self.smpl_t.Stop()                                  # タイマー終了
            TUSBSVM.Tusbs01vm_Device_Close(self.DevId)              # デバイスクローズ
            self.form.destroy()                                     # フォームを閉じる
            self.DevId = None
    
    def SmplStart(self):
        """サンプリングを開始する"""
        self.BtnStart['text'] = self.SMPL_BTN_STOP
        self.smpl_t.Start()                                         # タイマー開始
        self.form.protocol('WM_DELETE_WINDOW',lambda: 'pass' )      # ×ボタンでFormを閉じない

    def SmplStop(self):
        """"サンプリングを停止する"""
        self.smpl_t.Stop()                                          # タイマー停止
        self.BtnStart['text'] = self.SMPL_BTN_START
        self.form.protocol('WM_DELETE_WINDOW',lambda: self.form.destroy())  # ×ボタンでFormを閉じる

    # timer -------------------------------------
    def SampleT(self):
        """サンプルタイマー"""
        vData = 0.0
        for cnt in range(100):
            ret = TUSBSVM.Tusbs01vm_Single_Sample(self.DevId)   # 電圧データの取得
            if ret[0] != 0:
                self.LbldVolt['text'] = "Error!"
                return
            vData += ret[1]
        vData /= 100.0
        self.LbldVolt['text'] = format(vData,"5.2f")
    
    # ボタン等ウィジットの操作イベントハンドラ ----------------------
    def BtnStart_on(self):
        """開始、停止ボタンハンドラ"""
        if self.BtnStart["text"] == self.SMPL_BTN_START:    # 測定開始
            self.SmplStart()
        else:                                               # 測定停止
            self.SmplStop()

    # フォームとウィジェットを生成する処理---------------------------
    def formgen(self):
        self.form = tk.Tk()
        form = self.form
        form.geometry('328x143')
        form.title('TUSB-S01VMx Sample Program (single)')

        self.LbldVolt = GetLabelDisp(form,"",0.3,0.35,0.35)
        GetLabel(form,"V",0.7,0.35)
        self.BtnStart = GetButton(form,self.SMPL_BTN_START,self.BtnStart_on,0.25,0.5,0.8)

# 実行部 ---------------------------------
if __name__=="__main__":
    DevId = 0
    if( len(sys.argv) >= 2 ):
        if sys.argv[1].isdigit():
            DevId = int(sys.argv[1])    # コマンドライン引数でID設定
    tmp = Tusbs01vm_Device(DevId=DevId)
    tmp.form.mainloop()
